#import "MSAddAnnotationViewController.h"

@interface MSAddAnnotationViewController () <MRMapViewDelegate>
@property (nonatomic, strong) MRMapView *mapView;
@property (nonatomic, strong) MRPointAnnotation *userAnnotation;
@property (nonatomic, strong) MRPointAnnotation *userAnnotation2;
@end

@implementation MSAddAnnotationViewController

- (id)initWithNibName:(NSString *)name bundle:(NSBundle *)bundle {
    if ((self = [super initWithNibName:name bundle:bundle])) {
        self.edgesForExtendedLayout = UIRectEdgeNone;
        
        UIBarButtonItem *button1 = [[UIBarButtonItem alloc] initWithTitle:@"Toggle" style:UIBarButtonItemStylePlain target:self action:@selector(toggleAnnotation)];
        self.navigationItem.rightBarButtonItems = @[button1];
    }
    return self;
}

#pragma mark - UIViewController

- (void)loadView {
    self.mapView = [[MRMapView alloc] init];
    self.mapView.delegate = self;
    self.mapView.mapKey = [MREditorKey keyForMap:MAP_ID app:APP_ID];
    self.view = self.mapView;
    
    self.userAnnotation = [[MRPointAnnotation alloc] init];
    self.userAnnotation.point = CGPointMake(872, 420);
    [self.mapView addAnnotation:self.userAnnotation];
    
    self.userAnnotation2 = [[MRPointAnnotation alloc] init];
    self.userAnnotation2.point = CGPointMake(100, 100);
}

#pragma mark - MSExampleViewController

+ (NSString *)exampleTitle {
    return @"Add Annotation";
}

+ (NSString *)exampleInfo {
    return @"Example of how to add custom annotations.\n\n"
    @"• Custom annotation with a smiley image and `Hello There` in the callout.\n"
    @"• Button to add/remove a second smiley annotation.\n";
}

#pragma mark - MRMapViewDelegate

- (MRAnnotationView *)mapView:(MRMapView *)mapView viewForAnnotation:(id<MRAnnotation>)annotation {
    if (annotation == self.userAnnotation || annotation == self.userAnnotation2) {
        MRAnnotationView *annotationView = [self.mapView dequeueReusableAnnotationViewWithIdentifier:@"a"];
        if (!annotationView) {
            UIImageView *smileyView = [[UIImageView alloc] initWithImage:[UIImage imageNamed:@"Smiley"]];
            smileyView.userInteractionEnabled = YES;
            
            UILabel *label = [UILabel new];
            label.text = @"Hello There!";
            label.font = [UIFont fontWithName:@"Papyrus" size:20];
            [label sizeToFit];
            label.frame = (CGRect) { .origin.x = 2, .origin.y = 4, .size = label.frame.size };
            
            // create a containing view to nudge the text down a bit
            UIView *container = [[UIView alloc] initWithFrame:label.bounds];
            [container addSubview:label];
            
            annotationView = [[MRAnnotationView alloc] initWithAnnotation:self.userAnnotation reuseIdentifier:@"a"];
            annotationView.frame = smileyView.bounds;
            annotationView.canShowCallout = YES;
            annotationView.leftCalloutAccessoryView = container;
            [annotationView addSubview:smileyView];
        }
        return annotationView;
    }
    return nil;
}

#pragma mark - Action

- (void)toggleAnnotation {
    if ([self.mapView.annotations containsObject:self.userAnnotation2]) {
        [self.mapView removeAnnotation:self.userAnnotation2];
    } else {
        [self.mapView addAnnotation:self.userAnnotation2];
    }
}

@end
