#import "MSCustomAnnotationViewController.h"

@interface MSCustomAnnotationViewController () <MRMapViewDelegate>
@property (nonatomic, strong) MRMapView *mapView;
@property (nonatomic) BOOL blueRestaurantIcons;
@end

@implementation MSCustomAnnotationViewController

- (id)initWithNibName:(NSString *)name bundle:(NSBundle *)bundle {
    if ((self = [super initWithNibName:name bundle:bundle])) {
        self.edgesForExtendedLayout = UIRectEdgeNone;
        
        UIBarButtonItem *button1 = [[UIBarButtonItem alloc] initWithTitle:@"Toggle Color" style:UIBarButtonItemStylePlain target:self action:@selector(toggleColorAction)];
        self.navigationItem.rightBarButtonItems = @[button1];
    }
    return self;
}

#pragma mark - UIViewController

- (void)loadView {
    self.mapView = [[MRMapView alloc] init];
    self.mapView.delegate = self;
    self.mapView.mapKey = [MREditorKey keyForMap:MAP_ID app:APP_ID];
    self.mapView.showsUserLocation = YES;
    self.view = self.mapView;
}

#pragma mark - MSExampleViewController

+ (NSString *)exampleTitle {
    return @"Custom Placemark Annotations";
}

+ (NSString *)exampleInfo {
    return @"Example of how to customize placemark annotations.\n\n"
    @"• Restrooms have a title of `W/C` and a callout with the text `Washroom`.\n"
    @"• Restaurants have a custom accessory view, icon, font, shadow and text color.\n"
    @"• Button to toggle restaurant color between red and blue.\n";
}

#pragma mark - MRMapViewDelegate

- (MRAnnotationView *)mapView:(MRMapView *)mapView viewForAnnotation:(id<MRAnnotation>)annotation {
    if ([annotation isKindOfClass:[MRPlacemark class]]) {
        MRPlacemark *placemark = annotation;
        if ([placemark.type hasPrefix:@"restroom"]) {
            placemark.name = @"W/C";
            placemark.title = @"Washroom";
            return nil;
        } else if ([placemark.type isEqualToString:@"restaurant"]) {
            MRPlacemarkAnnotationView *defaultView = (MRPlacemarkAnnotationView *)[mapView defaultViewForAnnotation:annotation];
            defaultView.leftCalloutAccessoryView = [[UIImageView alloc] initWithImage:[UIImage imageNamed:@"Signal_3"]];
            if (self.blueRestaurantIcons) {
                defaultView.iconBackgroundColor = [UIColor blueColor];
            } else {
                defaultView.iconBackgroundColor = [UIColor redColor];
            }
            defaultView.shadowColor = [UIColor greenColor];
            defaultView.textColor = [UIColor grayColor];
            defaultView.font = [UIFont fontWithName:@"Papyrus" size:14];
            return defaultView;
        }
    }
    return nil;
}

#pragma mark - Action

- (void)toggleColorAction {
    self.blueRestaurantIcons = !self.blueRestaurantIcons;
    for (MRPlacemark *i in self.mapView.placemarks) {
        if ([i.type isEqualToString:@"restaurant"]) {
            MRPlacemarkAnnotationView *view = (id)[self.mapView viewForAnnotation:i];
            if (self.blueRestaurantIcons) {
                view.iconBackgroundColor = [UIColor blueColor];
            } else {
                view.iconBackgroundColor = [UIColor redColor];
            }
        }
    }
}

@end
