#import "MSOverlayViewController.h"

@interface MSOverlayViewController () <MRMapViewDelegate>
@property (nonatomic, strong) MRMapView *mapView;
@property (nonatomic, strong) MRPathOverlay *pathOverlay;
@end

@implementation MSOverlayViewController

- (id)initWithNibName:(NSString *)name bundle:(NSBundle *)bundle {
    if ((self = [super initWithNibName:name bundle:bundle])) {
        self.edgesForExtendedLayout = UIRectEdgeNone;
        UIBarButtonItem *button1 = [[UIBarButtonItem alloc] initWithTitle:@"Toggle Overlay" style:UIBarButtonItemStylePlain target:self action:@selector(toggleOverlay)];
        self.navigationItem.rightBarButtonItems = @[button1];
    }
    return self;
}

#pragma mark - UIViewController

- (void)loadView {
    self.mapView = [[MRMapView alloc] init];
    self.mapView.delegate = self;
    self.mapView.mapKey = [MREditorKey keyForMap:MAP_ID app:APP_ID];
    self.view = self.mapView;
}

#pragma mark - MRMapViewDelegate

- (MRPathRenderer *)mapView:(MRMapView *)mapView rendererForOverlay:(MRPathOverlay *)overlay {
    MRPathRenderer *renderer = [[MRPathRenderer alloc] initWithOverlay:overlay];
    renderer.strokeColor = [UIColor colorWithRed:0.000 green:0.478 blue:1.000 alpha:1];
    renderer.fillColor = [UIColor colorWithRed:0.000 green:0.478 blue:1.000 alpha:0.4];
    renderer.lineWidth = 20;
    renderer.lineCap = kCGLineCapRound;
    renderer.lineJoin = kCGLineJoinBevel;
    return renderer;
}

- (void)mapView:(MRMapView *)mapView didAddOverlayRenderers:(NSArray *)renderers {
    // no-op
}

#pragma mark - MSExampleViewController

+ (NSString *)exampleTitle {
    return @"Custom Overlays";
}

+ (NSString *)exampleInfo {
    return @"Example of how to add custom overlays.\n\n"
    @"• Button to toggle the appearance of a circular green overlay.\n";
}

#pragma mark - Internal

- (void)toggleOverlay {
    if (!self.pathOverlay) {
        self.pathOverlay = [[MRPathOverlay alloc] initWithCircleOfCenter:CGPointMake(200, 200) radius:50];
        [self.mapView addOverlay:self.pathOverlay];
    } else {
        [self.mapView removeOverlay:self.pathOverlay];
        self.pathOverlay = nil;
    }
}

@end
