#import "MSShowsButtonsViewController.h"

@interface MSShowsButtonsViewController () <MRMapViewDelegate>
@property (nonatomic, strong) MRMapView *mapView;
@property (nonatomic, strong) MRDirections *directions;
@end

@implementation MSShowsButtonsViewController

- (id)initWithNibName:(NSString *)name bundle:(NSBundle *)bundle {
    if ((self = [super initWithNibName:name bundle:bundle])) {
        self.edgesForExtendedLayout = UIRectEdgeNone;
        UIBarButtonItem *button1 = [[UIBarButtonItem alloc] initWithTitle:@"Map" style:UIBarButtonItemStylePlain target:self action:@selector(toggleLevels)];
        UIBarButtonItem *button2 = [[UIBarButtonItem alloc] initWithTitle:@"Over." style:UIBarButtonItemStylePlain target:self action:@selector(toggleOverview)];
        UIBarButtonItem *button3 = [[UIBarButtonItem alloc] initWithTitle:@"Loc." style:UIBarButtonItemStylePlain target:self action:@selector(toggleLocation)];
        UIBarButtonItem *button4 = [[UIBarButtonItem alloc] initWithTitle:@"Acc." style:UIBarButtonItemStylePlain target:self action:@selector(toggleAccessibility)];
        UIBarButtonItem *button5 = [[UIBarButtonItem alloc] initWithTitle:@"Dir." style:UIBarButtonItemStylePlain target:self action:@selector(toggleDirections)];
        self.navigationItem.rightBarButtonItems = @[button1, button2, button3, button4, button5];
    }
    return self;
}

#pragma mark - UIViewController

- (void)loadView {
    self.mapView = [[MRMapView alloc] init];
    self.mapView.delegate = self;
    self.mapView.showsUserLocation = YES;
    self.mapView.mapKey = [MREditorKey keyForMap:MAP_ID app:APP_ID];
    self.view = self.mapView;
}

#pragma mark - MSExampleViewController

+ (NSString *)exampleTitle {
    return @"Button Visibility";
}

+ (NSString *)exampleInfo {
    return @"Example of how to show/hide map buttons.\n\n"
    @"• `Dir.` button to start and stop directions.\n"
    @"• `Acc.` button to toggle accessibility button visibility.\n"
    @"• `Loc.` button to toggle location button visibility.\n"
    @"• `Over.` button to toggle overview button visibility.\n"
    @"• `Map` button to toggle map picker visibility.\n";
}

#pragma mark - Action

- (void)toggleDirections {
    if (!self.mapView.route) {
        MRDirectionsRequest *request = [[MRDirectionsRequest alloc] init];
        request.app = self.mapView.mapKey.parent;
        request.destination = [MRDirectionsDestination destinationWithPlacemarkKey:((MRPlacemark *)self.mapView.placemarks[0]).key];
        request.source = [MRDirectionsSource sourceWithPlacemarkKey:((MRPlacemark *)self.mapView.placemarks[1]).key];
        
        __weak typeof(self) weakSelf = self;
        self.directions = [[MRDirections alloc] initWithRequest:request presentingViewController:self];
        [self.directions calculateDirectionsWithCompletionHandler:^(MRDirectionsResponse *response, NSError *error) {
            [weakSelf directionsResponseDidLoad:response error:error];
        }];
    } else {
        self.mapView.route = nil;
    }
}

- (void)toggleLevels {
    self.mapView.showsMapPicker = !self.mapView.showsMapPicker;
}

- (void)toggleOverview {
    self.mapView.showsOverviewButton = !self.mapView.showsOverviewButton;
}

- (void)toggleLocation {
    self.mapView.showsLocationButton = !self.mapView.showsLocationButton;
}

- (void)toggleAccessibility {
    self.mapView.showsAccessibilityButton = !self.mapView.showsAccessibilityButton;
}

#pragma mark - Internal

- (void)directionsResponseDidLoad:(MRDirectionsResponse *)response error:(NSError *)error {
    self.directions = nil;
    if (!error && response.routes.count > 0) {
        self.mapView.route = response.routes.firstObject;
    } else {
        UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"Could not load directions" message:error.localizedDescription preferredStyle:UIAlertControllerStyleAlert];
        UIAlertAction *action = [UIAlertAction actionWithTitle:@"Ok" style:UIAlertActionStyleDefault handler:nil];
        [alertController addAction:action];
        [self presentViewController:alertController animated:YES completion:nil];
    }
}

@end
