//
//  MSCustomAnnotationViewController.swift
//  MeridianSwiftSamples
//
//  Created by Stephen Kelly on 5/19/17.
//  Copyright © 2017 Aruba Networks. All rights reserved.
//

import UIKit

class MSCustomAnnotationViewController: UIViewController, MRMapViewDelegate, MSExampleViewController {
    private lazy var mapView: MRMapView = {
        let mapView = MRMapView()
        mapView.showsUserLocation = true
        mapView.delegate = self
        mapView.mapKey = MREditorKey(forMap:MAP_ID, app:APP_ID)
        return mapView
    }()

    private var blueRestaurantIcons = false

    override func viewDidLoad() {
        super.viewDidLoad()
        self.view = self.mapView

        let button0 = UIBarButtonItem(title: "Toggle Color", style: .plain, target: self, action: #selector(self.toggleColorAction))
        self.navigationItem.rightBarButtonItems = [button0]
    }

    // MARK: - MSExampleViewController

    static func exampleTitle() -> String {
        return "Custom Placemark Annotations"
    }

    static func exampleDetail() -> String {
        return "Example of how to customize placemark annotations.\n\n" +
            "• Restrooms have a title of `W/C` and a callout with the text `Washroom`.\n" +
            "• Restaurants have a custom accessory view, icon, font, shadow and text color.\n" +
            "• Button to toggle restaurant color between red and blue.\n"
    }

    // MARK: - MRMapViewDelegate

    func mapView(_ mapView: MRMapView, viewFor annotation: MRAnnotation?) -> MRAnnotationView? {
        guard let placemark = annotation as? MRPlacemark, let type = placemark.type else {
            return nil
        }
        if type.hasPrefix("restroom") {
            placemark.name = "W/C"
            placemark.title = "Washroom"
            return nil
        } else if type == "restaurant" {
            guard let defaultView = mapView.defaultView(for: placemark) as? MRPlacemarkAnnotationView else {
                return nil
            }
            defaultView.leftCalloutAccessoryView = UIImageView(image: #imageLiteral(resourceName: "Signal_3"))
            if self.blueRestaurantIcons {
                defaultView.iconBackgroundColor = UIColor.blue
            } else {
                defaultView.iconBackgroundColor = UIColor.red
            }
            defaultView.shadowColor = UIColor.green
            defaultView.textColor = UIColor.gray
            defaultView.font = UIFont(name: "Papyrus", size: 14)
            return defaultView
        }
        return nil
    }

    // MARK: - Action

    @objc private func toggleColorAction() {
        self.blueRestaurantIcons = !self.blueRestaurantIcons
        for case let placemark as MRPlacemark in self.mapView.placemarks {
            if let type = placemark.type, type == "restaurant" {
                guard let view = self.mapView.view(for: placemark) as? MRPlacemarkAnnotationView else {
                    continue
                }
                if self.blueRestaurantIcons {
                    view.iconBackgroundColor = UIColor.blue
                } else {
                    view.iconBackgroundColor = UIColor.red
                }
            }
        }
    }
}
