//
//  MSFriendMapViewController.swift
//  MeridianSwiftSamples
//
//  Created by Stephen Kelly on 5/23/17.
//  Copyright © 2017 Aruba Networks. All rights reserved.
//

import UIKit

class MSFriendMapViewController: UIViewController, MRMapViewDelegate, MRSharingSessionDelegate {
    var friends = [MRFriend]()
    var session: MRSharingSession? {
        willSet (newValue) {
            newValue?.delegate = self
        }
    }

    private lazy var mapView: MRMapView = {
        let mapView = MRMapView()
        mapView.delegate = self
        mapView.mapKey = MREditorKey(forMap:MAP_ID, app:APP_ID)
        mapView.showsUserLocation = true
        return mapView
    }()

    override func viewDidLoad() {
        super.viewDidLoad()
        self.view = self.mapView
    }

    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        self.reloadAnnotations()
    }

    // MARK: - MRMapViewDelegate

    func mapViewDidFinishLoadingMap(_ mapView: MRMapView) {
        self.reloadAnnotations()
    }

    // MARK: - MRSharingSessionDelegate

    func sharingSession(_ session: MRSharingSession, didFailWithError error: Error) {
        // noop
    }

    func sharingSession(_ session: MRSharingSession, friendsDidUpdate friends: [MRFriend]) {
        self.friends = friends
        self.reloadAnnotations()
    }

    // MARK: - Internal

    private func reloadAnnotations() {
        var myFriendsOnMap = [MRFriend]()
        for friend in self.friends {
            guard let mapKey = friend.location?.mapKey else {
                continue
            }
            if mapKey == self.mapView.mapKey {
                myFriendsOnMap.append(friend)
            }
        }

        var toRemove = [MRAnnotation]()
        for case let annotation as MRFriend in self.mapView.annotations {
            toRemove.append(annotation)
        }

        self.mapView.removeAnnotations(toRemove)
        self.mapView.addAnnotations(myFriendsOnMap)
    }
}
