//
//  MSVisibleMapRectViewController.swift
//  MeridianSwiftSamples
//
//  Created by Stephen Kelly on 5/19/17.
//  Copyright © 2017 Aruba Networks. All rights reserved.
//

import UIKit

class MSVisibleMapRectViewController: UIViewController, MRMapViewDelegate, MSExampleViewController {
    private lazy var mapView: MRMapView = {
        let mapView = MRMapView()
        mapView.delegate = self
        mapView.mapKey = MREditorKey(forMap:MAP_ID, app:APP_ID)
        return mapView
    }()

    override func viewDidLoad() {
        super.viewDidLoad()
        self.view = self.mapView

        let button0 = UIBarButtonItem(title: "Zoom", style: .plain, target: self, action: #selector(self.zoomAction))
        let button1 = UIBarButtonItem(title: "Overview", style: .plain, target: self, action: #selector(self.overviewAction))
        self.navigationItem.rightBarButtonItems = [button0, button1]
    }

    // MARK: - MSExampleViewController

    static func exampleTitle() -> String {
        return "Zoom and Rotation"
    }

    static func exampleDetail() -> String {
        return "Example of how to programatically change the visible map rect.\n\n" +
            "• Map starts zoomed to the upper left corner.\n" +
            "• Button to show the full map.\n" +
            "• Button to zoom onto the 'Widu' placemark.\n"
    }

    // MARK: - MRMapViewDelegate

    func mapViewDidFinishLoadingMap(_ mapView: MRMapView) {
        self.mapView.setVisibleMapRect(CGRect(x:100, y:100, width:100, height:100), animated: false, completion: nil)
    }

    // MARK: - Action

    @objc private func zoomAction() {
        for i in self.mapView.placemarks {
            if let placemarkTitle = i.title, placemarkTitle == "Widu" {
                let width: CGFloat = 15 * self.mapView.map.unitsPerMeter
                let visibleRect = CGRect(x:i.point.x - width/2, y:i.point.y - width/2, width:width, height:width)
                self.mapView.setVisibleMapRect(visibleRect, rotationAngle: CGFloat(Double.pi/4), animated: true, completion: nil)
            }
        }
    }

    @objc private func overviewAction() {
        let map = self.mapView.map
        self.mapView.setVisibleMapRect(CGRect(x:0, y:0, width:map.size.width, height:map.size.height), animated: true, completion: nil)
    }
}
